sequencetools.partition_sequence_by_sign_of_elements
====================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_by_sign_of_elements.partition_sequence_by_sign_of_elements
